@@ -9,10 +9,12 @@ package Data::Random;
 ################################################################################
 # - Modules and Libraries
 ################################################################################
+use strict;
+use warnings;
 use 5.005_62;
 
 use Carp qw(cluck);
-
+use Time::Piece;
 #use Data::Random::WordList;
 
 require Exporter;
@@ -47,7 +49,7 @@ use vars qw(
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 @EXPORT    = qw();
 
-$Data::Random::VERSION = '0.09_01';
+$Data::Random::VERSION = '0.11_2';
 
 ################################################################################
 # - Subroutines
@@ -100,7 +102,7 @@ sub rand_words {
         require Data::Random::WordList;
 
         # Create a new wordlist object
-        $wl = new Data::Random::WordList( wordlist => $options{'wordlist'} );
+        $wl = Data::Random::WordList->new( wordlist => $options{'wordlist'} );
     }
 
     # Get the random words
@@ -258,56 +260,41 @@ sub rand_date {
     # Get the options hash
     my %options = @_;
 
-    # use the Date::Calc module
-    eval q{ use Date::Calc };
-
-    cluck($@) && return if $@;
-
-    my ( $min_year, $min_month, $min_day, $max_year, $max_month, $max_day );
-
+    my $min;
+    my $max;
     # Get today's date
-    my ( $year, $month, $day ) = Date::Calc::Today();
+    my $t = localtime;
+    my ( $year, $month, $day ) = split('-', $t->ymd);
+    my $today = Time::Piece->strptime($t->ymd, "%Y-%m-%d");
 
     if ( $options{'min'} ) {
         if ( $options{'min'} eq 'now' ) {
-            ( $min_year, $min_month, $min_day ) = ( $year, $month, $day );
+            $min = $today;
         }
         else {
-            ( $min_year, $min_month, $min_day ) =
-              split ( /\-/, $options{'min'} );
+            $min = Time::Piece->strptime($options{'min'}, '%Y-%m-%d');
         }
     }
     else {
-        ( $min_year, $min_month, $min_day ) = ( $year, $month, $day );
+        $min = $today;
     }
-
     if ( $options{'max'} ) {
         if ( $options{'max'} eq 'now' ) {
-            ( $max_year, $max_month, $max_day ) = ( $year, $month, $day );
+            $max = $today;
         }
         else {
-            ( $max_year, $max_month, $max_day ) =
-              split ( /\-/, $options{'max'} );
+            $max = Time::Piece->strptime($options{max}, "%Y-%m-%d");
         }
     }
     else {
-        ( $max_year, $max_month, $max_day ) =
-          Date::Calc::Add_Delta_YMD( $min_year, $min_month, $min_day, 1, 0, 0 );
+          $max = $min->add_years(1);
     }
 
-    my $delta_days =
-      Date::Calc::Delta_Days( $min_year, $min_month, $min_day, $max_year,
-        $max_month, $max_day, );
-
+    my $delta_days = int($max->julian_day) - int($min->julian_day);
     cluck('max date is later than min date') && return if $delta_days < 0;
 
-    $delta_days = int( rand( $delta_days + 1 ) );
-
-    ( $year, $month, $day ) =
-      Date::Calc::Add_Delta_Days( $min_year, $min_month, $min_day,
-        $delta_days );
-
-    return sprintf( "%04u-%02u-%02u", $year, $month, $day );
+    my $result = $min + ( 3600 * 24  * int( rand($delta_days + 1) ) );
+    return $result->ymd;
 }
 
 ################################################################################
@@ -392,79 +379,54 @@ sub rand_datetime {
     # Get the options hash
     my %options = @_;
 
-    # use the Date::Calc module
-    eval q{ use Date::Calc };
-
-    cluck($@) && return if $@;
-
-    my (
-        $min_year, $min_month, $min_day, $min_hour, $min_min, $min_sec,
-        $max_year, $max_month, $max_day, $max_hour, $max_min, $max_sec
-    );
-
     # Get today's date
-    my ( $year, $month, $day, $hour, $min, $sec ) = Date::Calc::Today_and_Now();
+    my $now = localtime;
+    my $minimum;
+    my $maximum;
 
-    if ( $options{'min'} ) {
-        if ( $options{'min'} eq 'now' ) {
-            ( $min_year, $min_month, $min_day,
-              $min_hour, $min_min,   $min_sec )
-              = ( $year, $month, $day, $hour, $min, $sec );
+    if ( $options{min} ) {
+        if ( $options{min} eq 'now' ) {
+            $minimum = Time::Piece->strptime(
+              $now->strftime('%Y-%m-%d %T'),
+              '%Y-%m-%d %T'
+            );
         }
         else {
-            ( $min_year, $min_month, $min_day,
-              $min_hour, $min_min,   $min_sec )
-              = $options{'min'} =~ /^(\d+)-(\d+)-(\d+) (\d+):(\d+):(\d+)$/;
+            $minimum = Time::Piece->strptime(
+              $options{min},
+              '%Y-%m-%d %T'
+            );
         }
     }
     else {
-        ( $min_year, $min_month, $min_day, $min_hour, $min_min, $min_sec ) =
-          ( $year, $month, $day, 0, 0, 0 );
+        $minimum = $now;
     }
 
-    if ( $options{'max'} ) {
-        if ( $options{'max'} eq 'now' ) {
-            ( $max_year, $max_month, $max_day,
-              $max_hour, $max_min,   $max_sec )
-              = ( $year, $month, $day, $hour, $min, $sec );
+    if ( $options{max} ) {
+        if ( $options{max} eq 'now' ) {
+            $maximum = Time::Piece->strptime(
+              $now->strftime('%Y-%m-%d %T'),
+              '%Y-%m-%d %T'
+            );
         }
         else {
-            ( $max_year, $max_month, $max_day,
-              $max_hour, $max_min,   $max_sec )
-              = $options{'max'} =~ /^(\d+)-(\d+)-(\d+) (\d+):(\d+):(\d+)$/;
+            $maximum = Time::Piece->strptime(
+              $options{max},
+              '%Y-%m-%d %T'
+            );
         }
     }
     else {
-        ( $max_year, $max_month, $max_day, $max_hour, $max_min, $max_sec ) =
-          ( Date::Calc::Add_Delta_YMD( $min_year, $min_month, $min_day, 1, 0,
-              0 ), 23, 59, 59 );
+        $maximum = $minimum->add_years(1);
     }
 
-    my ( $delta_days, $delta_hours, $delta_mins, $delta_secs ) =
-      Date::Calc::Delta_DHMS(
-        $min_year, $min_month, $min_day, $min_hour, $min_min, $min_sec,
-        $max_year, $max_month, $max_day, $max_hour, $max_min, $max_sec,
-    );
-
-    cluck('max date is later than min date') && return
-      if ( $delta_days < 0 ) || ( $delta_hours < 0 ) || ( $delta_mins < 0 )
-      || ( $delta_secs < 0 );
-
-    $delta_secs =
-      ( $delta_days * 86400 ) + ( $delta_hours * 3600 ) + ( $delta_mins * 60 ) +
-      $delta_secs;
-
+    my $delta_secs = $maximum - $minimum;
+    cluck('max_date is later than min date') && return if $delta_secs < 0;
     $delta_secs = int( rand( $delta_secs + 1 ) );
 
-    ( $year, $month, $day, $hour, $min, $sec ) = Date::Calc::Add_Delta_DHMS(
-        $min_year, $min_month, $min_day, $min_hour,
-        $min_min,  $min_sec,   0,        0,
-        0,         $delta_secs
-    );
+    my $result = $minimum + $delta_secs;
 
-    return
-      sprintf( "%04u-%02u-%02u %02u:%02u:%02u", $year, $month, $day, $hour,
-        $min, $sec );
+    return $result->strftime('%Y-%m-%d %T');
 }
 
 ################################################################################
@@ -475,6 +437,9 @@ sub rand_image {
     # Get the options hash
     my %options = @_;
 
+    eval q{ require GD; };
+    cluck($@) && return if $@;
+
     $options{'minwidth'} ||= 1;
     $options{'maxwidth'} ||= 100;
     $options{'width'} ||=
@@ -496,11 +461,7 @@ sub rand_image {
     $options{'bgcolor'} ||= _color();
     $options{'fgcolor'} ||= _color();
 
-    eval q{ use GD; };
-
-    cluck($@) && return if $@;
-
-    my $image = new GD::Image( $options{'width'}, $options{'height'} );
+    my $image = GD::Image->new( $options{'width'}, $options{'height'} );
 
     my $bgcolor = $image->colorAllocate( @{ $options{'bgcolor'} } );
     my $fgcolor = $image->colorAllocate( @{ $options{'fgcolor'} } );
@@ -517,7 +478,7 @@ sub rand_image {
     return $image->png();
 
     sub _color {
-        return [ int( rand(266) ), int( rand(266) ), int( rand(266) ) ];
+        return [ int( rand(256) ), int( rand(256) ), int( rand(256) ) ];
     }
 }
 
@@ -562,10 +523,10 @@ Data::Random - Perl module to generate random data
 
   my $random_datetime = rand_datetime();
 
-  open(FILE, ">rand_image.png") or die $!;
-  binmode(FILE);
-  print FILE rand_image( bgcolor => [0, 0, 0] );
-  close(FILE);
+  open(my $file, ">", "rand_image.png") or die $!;
+  binmode($file);
+  print $file rand_image( bgcolor => [0, 0, 0] );
+  close($file);
 
 
 =head1 DESCRIPTION
@@ -834,7 +795,7 @@ fgcolor - the foreground color of the image.  The value must be a reference to a
 
 =head1 VERSION
 
-0.09
+0.11_2
 
 
 =head1 AUTHOR
@@ -848,11 +809,14 @@ Currently maintained by: Buddy Burden (barefoot@cpan.org), starting with version
 
     Hiroki Chalfant
     David Sarno
+	Michiel Beijen
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2011 Adekunle Olonoh.  All rights reserved.  This program is free software; you
+Copyright (c) 2000-2011 Adekunle Olonoh.
+Copyright (c) 2011-2015 Buddy Burden.
+All rights reserved.  This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl itself.
 
 
