@@ -12,14 +12,16 @@ package Data::Random::WordList;
 ################################################################################
 # - Modules and Libraries
 ################################################################################
-#require 5.005_62;
+use strict;
+use warnings;
+
 use FileHandle;
 use File::Basename qw(dirname);
 
 ################################################################################
 # - Global Constants and Variables
 ################################################################################
-$Data::Random::WordList::VERSION = '0.07_001';
+$Data::Random::WordList::VERSION = '0.11_2';
 
 ################################################################################
 # - Subroutines
@@ -173,7 +175,7 @@ Closes the filehandle associated with the word list.  It's good practice to do t
 
 =head1 VERSION
 
-0.07
+0.11_2
 
 
 =head1 AUTHOR
@@ -185,7 +187,9 @@ Currently maintained by: Buddy Burden (barefoot@cpan.org), starting with version
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2011 Adekunle Olonoh.  All rights reserved.  This program is free software; you
+Copyright (c) 2000-2011 Adekunle Olonoh.
+Copyright (c) 2011-2015 Buddy Burden.
+All rights reserved.  This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl itself.
 
 
